package com.logicbig.example;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class NamedCapturingGroupExample {
    private final static String regex =
            "\\b(?<city>[A-Za-z\\s]+),\\s(?<state>[A-Z]{2,2}):\\s(?<areaCode>[0-9]{3,3})\\b";
    private final static Pattern pattern = Pattern.compile(regex);

    public void showAreaCodes(String textData) {
        List<PhoneAreaCode> areaCodeList = getAreaCodeList(textData);
        System.out.println(areaCodeList);
    }

    public List<PhoneAreaCode> getAreaCodeList(String textData) {
        List<PhoneAreaCode> areaCodeList = new ArrayList<>();
        Matcher matcher = pattern.matcher(textData);

        while (matcher.find()) {
            if (matcher.groupCount() == 3) {
                areaCodeList.add(
                        new PhoneAreaCode(matcher.group("city"), matcher.group("state"),
                                matcher.group("areaCode")));
            }
        }
        return areaCodeList;
    }

    public static void main(String[] args) {
        String input = "This is the list: Baytown, TX: 281, Chapel Hill, NC: 284, " +
                "Fort Myers, FL: 239";
        new NamedCapturingGroupExample().showAreaCodes(input);
    }
}